@@ -1,5 +1,6 @@
 /********************************************************************
 Copyright 2018 Roman Gilg <subdiff@gmail.com>
+Copyright 2021 David Redondo <kde@david-redondo.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,22 +18,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "globals.h"
 
 #include <QStandardPaths>
+#include <QStringBuilder>
 
 namespace Globals
 {
-QString s_dirPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) % QStringLiteral("/kscreen/");
 
 QString dirPath()
 {
-    return s_dirPath;
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) % QStringLiteral("/kscreen/");
 }
 
-void setDirPath(const QString &path)
+QString findFile(const QString &filePath)
 {
-    s_dirPath = path;
-    if (!s_dirPath.endsWith(QLatin1Char('/'))) {
-        s_dirPath += QLatin1Char('/');
-    }
+    return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kscreen/") % filePath);
 }
-
 }
